searchData={"items":[{"type":"module","title":"OpentelemetryTelemetry","doc":"`OpentelemetryTelemetry` provides conveniences for leveraging `telemetry`\nevents for `OpenTelemetry` bridge libraries.","ref":"OpentelemetryTelemetry.html"},{"type":"module","title":"OpenTelemetry Contexts - OpentelemetryTelemetry","doc":"`opentelemetry` does not automatically set current span context when ending\nanother span. Since `telemetry` events are executed in separate handlers with\nno shared context, correlating individual events requires a mechanism to do so.\nAdditionally, when ending telemetry-based spans, the user must set the correct\nparent context back as the current context. This ensures sibling spans are\ncorrectly correlated to the shared parent span.\n\nThis library provides helper functions to manage contexts automatically with\n`start_telemetry_span/4`, `set_current_telemetry_span/2`, and `end_telemetry_span/2`\nto give bridge library authors a mechanism for working with these challenges. Once\n`start_telemetry_span/4` or `set_current_telemetry_span/2` are called, users\ncan use all of `OpenTelemetry` as normal. By providing the application tracer id\nand the event's metadata, the provided span functions will identify and manage\nspan contexts automatically.","ref":"OpentelemetryTelemetry.html#module-opentelemetry-contexts"},{"type":"module","title":"Example Telemetry Event Handlers - OpentelemetryTelemetry","doc":"```\n  def handle_event(_event,\n            %{system_time: start_time},\n            metadata,\n            %{type: :start, tracer_id: tracer_id, span_name: name}) do\n    start_opts = %{start_time: start_time}\n    OpentelemetryTelemetry.start_telemetry_span(tracer_id, name, metadata, start_opts)\n    :ok\n  end\n\n  def handle_event(_event,\n              %{duration: duration},\n              metadata,\n              %{type: :stop, tracer_id: tracer_id}) do\n      OpentelemetryTelemetry.set_current_telemetry_span(tracer_id, metadata)\n      OpenTelemetry.Tracer.set_attribute(:duration, duration)\n      OpentelemetryTelemetry.end_telemetry_span(tracer_id, metadata)\n      :ok\n  end\n\n  def handle_event(_event,\n              %{duration: duration},\n              %{kind: kind, reason: reason, stacktrace: stacktrace} = metadata,\n              %{type: :exception, tracer_id: tracer_id}) do\n      ctx = OpentelemetryTelemetry.set_current_telemetry_span(tracer_id, metadata),\n      status = Opentelemetry.status(:error, to_string(reason, :utf8))\n      OpenTelemetry.Span.record_exception(ctx, kind, reason, stacktrace, [duration: duration])\n      OpenTelemetry.Tracer.set_status(status)\n      OpentelemetryTelemetry.end_telemetry_span(tracer_id, metadata)\n      :ok\n    end\n  def handle_event(_event, _measurements, _metadata, _config), do: :ok\n\n```","ref":"OpentelemetryTelemetry.html#module-example-telemetry-event-handlers"},{"type":"module","title":"Limitations - OpentelemetryTelemetry","doc":"Span contexts are currently stored in the process dictionary, so spans can only\nbe correlated within a single process at this time. This covers the primary use\ncase where library authors have implemented `telemetry:with_span` or the pattern\nestablished in said function. Non-library authors should use opentelemetry directly\nwherever possible.\n\nIf the `event_metadata` includes a `telemetry_span_context` (introduced in telemetry\n`v0.4.3`), contexts are correlated by the `telemetry_span_context` id to guarantee\nthe correct otel span context. Span events in earlier versions of `telemetry` are stored\nin a stack by `tracer_id` to lessen the likelihood of inadvertently closing the wrong\nspan.","ref":"OpentelemetryTelemetry.html#module-limitations"},{"type":"function","title":"OpentelemetryTelemetry.end_telemetry_span/2","doc":"End a telemetry-based span based on the `tracer_id` and telemetry event metadata\nand restore the current ctx to the span's parent ctx.","ref":"OpentelemetryTelemetry.html#end_telemetry_span/2"},{"type":"function","title":"OpentelemetryTelemetry.set_current_telemetry_span/2","doc":"Set the current span ctx based on the tracer_id and telemetry event metadata.","ref":"OpentelemetryTelemetry.html#set_current_telemetry_span/2"},{"type":"function","title":"OpentelemetryTelemetry.start_telemetry_span/4","doc":"Start a telemetry-based span.","ref":"OpentelemetryTelemetry.html#start_telemetry_span/4"},{"type":"type","title":"OpentelemetryTelemetry.ctx_set/0","doc":"","ref":"OpentelemetryTelemetry.html#t:ctx_set/0"},{"type":"type","title":"OpentelemetryTelemetry.parent_span_ctx/0","doc":"The parent span ctx for a telemetry-based span. This is what the current span ctx was\nat the time of starting a telemetry-based span.","ref":"OpentelemetryTelemetry.html#t:parent_span_ctx/0"},{"type":"type","title":"OpentelemetryTelemetry.telemetry_span_ctx/0","doc":"A span ctx for a telemetry-based span.","ref":"OpentelemetryTelemetry.html#t:telemetry_span_ctx/0"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]},"content_type":"text/markdown"}